==> burf-1.0.3.tar.gz: burf-1.0.3/burf/storage.py <==
from abc import ABC, abstractmethod
from google.cloud.storage import Client  # type: ignore
from google.auth.credentials import Credentials
from typing import List, Optional


class Dir:
    def __init__(self, name: str):
        self.name = name

    __match_args__ = ("name",)


class Blob:
    def __init__(self, name: str, size: int):
        self.name = name
        self.size = size

    __match_args__ = ("name", "size")


class Storage(ABC):
    @abstractmethod
    def list_buckets(self) -> List[Dir]:
        pass

    @abstractmethod
    def list_prefix(self, bucket_name: str, prefix: str) -> List[Dir | Blob]:
        pass

    @abstractmethod
    def get_project(self):
        pass


class GCS(Storage):
    credentials: Optional[Credentials]
    project: str | object
    client: Client

    def __init__(
        self, credentials: Optional[Credentials] = None, project: Optional[str] = None
    ):
        self.credentials = credentials
        self.project = project
        self.build_client()

    def set_credentials(self, credentials: Credentials) -> None:
        self.credentials = credentials
        self.build_client()

    def set_project(self, project: str) -> None:
        self.project = project
        self.build_client()

    def get_project(self):
        if self.project is not None:
            return self.project
        else:
            return self.client.project

    def build_client(self):
        if self.project is not None:
            self.client = Client(credentials=self.credentials, project=self.project)
        else:
            self.client = Client(credentials=self.credentials)

    def list_buckets(self) -> List[Dir]:
        buckets = self.client.list_buckets()
        return [Dir(bucket.name) for bucket in buckets]

    def list_prefix(self, bucket_name: str, prefix: str) -> List[Dir | Blob]:
        blobs = self.client.bucket(bucket_name).list_blobs(delimiter="/", prefix=prefix)
        blob_list = list(blobs)

        result = [Dir(subdir) for subdir in blobs.prefixes] + [
            Blob(blob.name, blob.size) for blob in blob_list
        ]

        sorted_result = sorted(result, key=lambda x: x.name)

        return sorted_result

==> burf-1.0.5.tar.gz: burf-1.0.5/burf/storage.py <==
from abc import ABC, abstractmethod
from google.cloud.storage import Client  # type: ignore
from google.auth.credentials import Credentials
from typing import List, Optional

from datetime import datetime


class Dir:
    def __init__(self, name: str):
        self.name = name

    __match_args__ = ("name",)


class Blob:
    def __init__(self, name: str, size: int, time_created: datetime):
        self.name = name
        self.size = size
        self.time_created = time_created

    __match_args__ = ("name", "size", "time_created")


class Storage(ABC):
    @abstractmethod
    def list_buckets(self) -> List[Dir]:
        pass

    @abstractmethod
    def list_prefix(self, bucket_name: str, prefix: str) -> List[Dir | Blob]:
        pass

    @abstractmethod
    def get_project(self):
        pass


class GCS(Storage):
    credentials: Optional[Credentials]
    project: str | object
    client: Client

    def __init__(
        self, credentials: Optional[Credentials] = None, project: Optional[str] = None
    ):
        self.credentials = credentials
        self.project = project
        self.build_client()

    def set_credentials(self, credentials: Credentials) -> None:
        self.credentials = credentials
        self.build_client()

    def set_project(self, project: str) -> None:
        self.project = project
        self.build_client()

    def get_project(self):
        if self.project is not None:
            return self.project
        else:
            return self.client.project

    def build_client(self):
        if self.project is not None:
            self.client = Client(credentials=self.credentials, project=self.project)
        else:
            self.client = Client(credentials=self.credentials)

    def list_buckets(self) -> List[Dir]:
        buckets = self.client.list_buckets()
        return [Dir(bucket.name) for bucket in buckets]

    def list_prefix(self, bucket_name: str, prefix: str) -> List[Dir | Blob]:
        blobs = self.client.bucket(bucket_name).list_blobs(delimiter="/", prefix=prefix)
        blob_list = list(blobs)

        result = [Dir(subdir) for subdir in blobs.prefixes] + [
            Blob(blob.name, blob.size, blob.time_created) for blob in blob_list
        ]

        sorted_result = sorted(result, key=lambda x: x.name)

        return sorted_result
